@@ -44,4 +44,14 @@ test_that("Selects/excludes in rows", {
     sum(is.na(as.matrix(focus(d, Sepal.Length, Sepal.Width, mirror = FALSE)))),
     0
   )
+})
+
+test_that("focus_if works", {
+  any_greater_than <- function(x, val) {
+    mean(abs(x), na.rm = TRUE) > val
+  }
+  expect_is(
+    focus_if(d, any_greater_than, .6),
+    "tbl_df"
+  )
 })
\ No newline at end of file
